@@ -52,6 +52,8 @@ code from qwriter:
 #include <QDir>
 #include <QXmlStreamReader>
 #include <QMimeData>
+#include <QFile>
+
 #include <QTimer>
 
 #include "document.h"
@@ -447,11 +449,10 @@ void CSyntaxHighlighterQRegularExpression::load_from_xml (const QString &fname)
                       if (! rg.isValid())
                          qDebug() << "! valid " << rg.pattern();
                       else
-                          //commentStartExpression = rg;
-                           {
-                            comment_start_expr.first = rg;
-                            comment_start_expr.second = true;
-                           }
+                          {
+                           comment_start_expr.first = rg;
+                           comment_start_expr.second = true;
+                          }
                      }
                   else
                   if (attr_type == "mcomment-end")
@@ -464,11 +465,10 @@ void CSyntaxHighlighterQRegularExpression::load_from_xml (const QString &fname)
                       if (! rg.isValid())
                          qDebug() << "! valid " << rg.pattern();
                       else
-                          //commentEndExpression = rg;
-                        {
-                         comment_end_expr.first = rg;
-                         comment_end_expr.second = true;
-                        }
+                          {
+                           comment_end_expr.first = rg;
+                           comment_end_expr.second = true;
+                          }
 
                      }
                   else
@@ -541,10 +541,6 @@ void CSyntaxHighlighterQRegularExpression::highlightBlock (const QString &text)
 
   int startIndex = 0;
 
- // if (! commentStartExpression.isValid() || ! commentEndExpression.isValid())
-   //  return;
-
-//  QRegularExpressionMatch m_start = commentStartExpression.match (text);
   QRegularExpressionMatch m_start = comment_start_expr.first.match (text);
 
 
@@ -553,7 +549,6 @@ void CSyntaxHighlighterQRegularExpression::highlightBlock (const QString &text)
 
   while (startIndex >= 0)
         {
-         //QRegularExpressionMatch m_end = commentEndExpression.match (text, startIndex);
          QRegularExpressionMatch m_end = comment_end_expr.first.match (text, startIndex);
 
          int endIndex = m_end.capturedStart();
@@ -570,7 +565,6 @@ void CSyntaxHighlighterQRegularExpression::highlightBlock (const QString &text)
 
          setFormat (startIndex, commentLength, fmt_multi_line_comment);
 
-//         m_start = commentStartExpression.match (text, startIndex + commentLength);
          m_start = comment_start_expr.first.match (text, startIndex + commentLength);
 
          startIndex = m_start.capturedStart();
@@ -826,9 +820,9 @@ CDocument::CDocument (CDox *hldr, QWidget *parent): QPlainTextEdit (parent)
 
   line_num_area = new CLineNumberArea (this);
 
-  connect(this, SIGNAL(selectionChanged()), this, SLOT(slot_selectionChanged()));
-  connect(this, SIGNAL(blockCountChanged(int)), this, SLOT(updateLineNumberAreaWidth()));
-  connect(this, SIGNAL(updateRequest(QRect, int)), this, SLOT(updateLineNumberArea(QRect, int)));
+  connect (this, SIGNAL(selectionChanged()), this, SLOT(slot_selectionChanged()));
+  connect (this, SIGNAL(blockCountChanged(int)), this, SLOT(updateLineNumberAreaWidth()));
+  connect (this, SIGNAL(updateRequest(QRect, int)), this, SLOT(updateLineNumberArea(QRect, int)));
   connect (this, SIGNAL(cursorPositionChanged()), this, SLOT(cb_cursorPositionChanged()));
 
   updateLineNumberAreaWidth();
@@ -873,21 +867,25 @@ CDocument::CDocument (CDox *hldr, QWidget *parent): QPlainTextEdit (parent)
 
 CDocument::~CDocument()
 {
+  if (holder->autosave_files.contains (file_name))
+     {
+      file_save_with_name (file_name, charset);
+      document()->setModified (false);
+     }
+
   if (file_name.endsWith (".notes") && document()->isModified())
      file_save_with_name_plain (file_name);
   else
   if (file_name.startsWith (holder->dir_config) && document()->isModified())
      file_save_with_name_plain (file_name);
   else
-  if (document()->isModified() && file_exists (file_name))
-     {
-      if (QMessageBox::warning (0, "TEA",
-                                tr ("%1 has been modified.\n"
-                                "Do you want to save your changes?").arg (file_name),
-                                QMessageBox::Yes | QMessageBox::Default,
-                                QMessageBox::No | QMessageBox::Escape) == QMessageBox::Yes)
-         file_save_with_name (file_name, charset);
-     }
+      if (document()->isModified() && file_exists (file_name))
+         if (QMessageBox::warning (0, "TEA",
+                                   tr ("%1 has been modified.\n"
+                                       "Do you want to save your changes?").arg (file_name),
+                                       QMessageBox::Yes | QMessageBox::Default,
+                                       QMessageBox::No | QMessageBox::Escape) == QMessageBox::Yes)
+            file_save_with_name (file_name, charset);
 
   if (! file_name.startsWith (holder->dir_config) && ! file_name.endsWith (".notes"))
      {
@@ -964,7 +962,6 @@ bool CDocument::file_open (const QString &fileName, const QString &codec)
                 i.remove();
         }
 
-
   return true;
 }
 
@@ -1981,8 +1978,12 @@ CDox::CDox()
   l_status_bar = 0;
   l_charset = 0;
 
-  timer = new QTimer (this);
-  timer->setInterval (100);
+  //timer_autosave = new QTimer (this);
+  timer_autosave.setInterval (settings->value ("timer_autosave_period", "1000").toInt() * 1000);
+  connect(&timer_autosave, SIGNAL(timeout()), this, SLOT(autosave()));
+
+  //timer_joystick = new QTimer (this);
+  timer_joystick.setInterval (100);
 
 #if defined(JOYSTICK_SUPPORTED)
 
@@ -1990,12 +1991,14 @@ CDox::CDox()
 
   if (joystick->initialized)
      {
-      connect(timer, SIGNAL(timeout()), joystick, SLOT(read_joystick()));
+      connect(&timer_joystick, SIGNAL(timeout()), joystick, SLOT(read_joystick()));
 
       if (settings->value ("use_joystick", "0").toBool())
-         timer->start();
+         timer_joystick.start();
      }
 #endif
+
+
 }
 
 
@@ -2260,6 +2263,47 @@ void CDox::load_from_session (const QString &fileName)
   fname_current_session = fileName;
 }
 
+void CDox::save_buffers (const QString &fileName)
+{
+  QFile::remove (fileName);
+
+  if (items.size() == 0)
+     return;
+
+  fname_current_session = fileName;
+  QString l;
+
+  for (vector <CDocument*>::iterator i = items.begin(); i != items.end(); ++i)
+      {
+       if (! file_exists ((*i)->file_name))
+          {
+           l += (*i)->toPlainText();
+           l += '\f';
+          }
+      }
+
+  qstring_save (fileName, l.trimmed());
+}
+
+
+void CDox::load_from_buffers (const QString &fileName)
+{
+  if (! file_exists (fileName))
+     return;
+
+  QStringList l = qstring_load (fileName).split ("\f");
+  if (l.size() < 0)
+     return;
+
+  for (int i = 0; i < l.size(); i++)
+      {
+       CDocument *d = create_new();
+       d->put (l[i]);
+      }
+
+  fname_current_session = fileName;
+}
+
 
 void CDox::apply_settings()
 {
@@ -2346,6 +2390,27 @@ void CDox::open_current()
 }
 
 
+void CDox::autosave()
+{
+//  log->log ("AUTOSAVE");
+
+  if (! settings->value ("autosave", false).toBool())
+      return;
+
+  if (items.size() == 0)
+     return;
+
+  for (vector <CDocument *>::iterator i = items.begin(); i != items.end(); ++i)
+      {
+       if (autosave_files.contains ((*i)->file_name))
+          (*i)->file_save_with_name ((*i)->file_name, (*i)->charset);
+      }
+
+  save_buffers (fname_saved_buffers);
+}
+
+
+
 void CDox::move_cursor_up()
 {
   move_cursor (QTextCursor::Up);
