@@ -289,6 +289,7 @@ public:
 
   QHash <QString, QString> markup_modes;
   QHash <QString, QString> hash_project;
+  QHash <QString, QString> autosave_files;
 
   CTioHandler tio_handler;
   CTodo todo;
@@ -298,6 +299,8 @@ public:
   QString fname_current_project;
   QString dir_config;
   QString fname_crapbook;
+  QString fname_saved_buffers;
+
   QString markup_mode;
   QString recent_list_fname;
 
@@ -308,7 +311,8 @@ public:
   QTabWidget *tab_widget; //uplink
   QTabWidget *main_tab_widget; //uplink
   QMenu *menu_recent; //uplink
-  QTimer *timer;
+  QTimer timer_joystick;
+  QTimer timer_autosave;
 
 #if defined(JOYSTICK_SUPPORTED)
   CJoystick *joystick;
@@ -333,8 +337,13 @@ public:
 
   void close_by_idx (int i);
   void close_current();
+
   void save_to_session (const QString &fileName);
   void load_from_session (const QString &fileName);
+
+  void save_buffers (const QString &fileName);
+  void load_from_buffers (const QString &fileName);
+
   void apply_settings();
   void apply_settings_single (CDocument *d);
 
@@ -349,6 +358,8 @@ public slots:
   void open_recent();
   void open_current();
 
+  void autosave();
+
   void move_cursor_up();
   void move_cursor_down();
   void move_cursor_left();
