@@ -46,17 +46,40 @@ DJVU read code taken fromdvutxt.c:
 
 #include <iostream>
 
+//#include <iconv.h>
+
+#include <QFile>
 #include <QXmlStreamReader>
+#include <QDataStream>
 #include <QTextStream>
 #include <QDebug>
+#include <QTextCodec>
 
 
-//FIXME: not good with cmake, cmake just use Qt5 here
-//#if defined (POPPLER_ENABLE) || defined(Q_OS_OS2)
+//////////////////FOR PDF
+#include <stdio.h>
+//YOur project must also include zdll.lib (ZLIB) as a dependency.
+//ZLIB can be freely downloaded from the internet, www.zlib.org
+//Use 4 byte struct alignment in your project!
+#include <zlib.h>
+//////////////////
+
+/*
+with cmake - Qt5/Qt6 poppler
+with qmake - Qt4/Qt5 poppler
+*/
+
 #if defined (POPPLER_ENABLE)
-#if QT_VERSION_MAJOR >= 5
+
+#if QT_VERSION_MAJOR == 6
+#include <poppler-qt6.h>
+#endif
+
+#if QT_VERSION_MAJOR == 5
 #include <poppler-qt5.h>
-#else
+#endif
+
+#if QT_VERSION_MAJOR == 4
 #include <poppler-qt4.h>
 #endif
 
@@ -126,15 +149,15 @@ QString extract_text_from_xml (const QString &string_data, const QStringList &ta
 
 bool CTioPlainText::load (const QString &fname)
 {
-  QFile feol_detector (fname);
+  QFile file (fname);
 
-  if (! feol_detector.open (QFile::ReadOnly))
+  if (! file.open (QFile::ReadOnly))
      {
-      error_string = feol_detector.errorString();
+      error_string = file.errorString();
       return false;
      }
 
-  QByteArray block = feol_detector.read (4096);
+  QByteArray block = file.read (4096);
 
   eol = "\n";
 
@@ -147,28 +170,14 @@ bool CTioPlainText::load (const QString &fname)
   if (block.indexOf ('\r') != -1)
      eol = "\r";
 
-/*
-   if (eol == "\n")
-     qDebug() << "LF";
-   if (eol == "\r\n")
-     qDebug() << "CRLF";
-   if (eol == "\r")
-     qDebug() << "CR";
-*/
+  file.seek(0);
 
-  feol_detector.close();
+//  QTextStream in (&file);
+ // in.setCodec (charset.toUtf8().data());
 
-  QFile file (fname);
-
-  if (! file.open (QFile::ReadOnly))
-     {
-      error_string = file.errorString();
-      return false;
-     }
-
-  QTextStream in (&file);
-  in.setCodec (charset.toUtf8().data());
-  data = in.readAll();
+  QByteArray ba = file.readAll();
+  QTextCodec *codec = QTextCodec::codecForName (charset.toUtf8().data());
+  data = codec->toUnicode (ba);
 
   if (eol == "\r\n")
      data.replace (eol, "\n");
@@ -176,6 +185,8 @@ bool CTioPlainText::load (const QString &fname)
   if (eol == "\r")
      data.replace (eol, "\n");
 
+  file.close();
+
   return true;
 }
 
@@ -189,9 +200,11 @@ bool CTioPlainText::save (const QString &fname)
       return false;
      }
 
-  QTextStream out (&file);
-  out.setCodec (charset.toUtf8().data());
-  out << data;
+  QTextCodec *codec = QTextCodec::codecForName(charset.toUtf8().data());
+  QByteArray ba = codec->fromUnicode(data);
+
+  file.write(ba);
+  file.close();
 
   return true;
 }
@@ -467,9 +480,9 @@ CCharsetMagic::~CCharsetMagic()
 
 
 //from https://stackoverflow.com/questions/28270310/how-to-easily-detect-utf8-encoding-in-the-string
-bool is_valid_utf8(const char * string)
+bool is_valid_utf8 (const char *string)
 {
-    if (!string)
+    if (! string)
         return true;
 
     const unsigned char * bytes = (const unsigned char *)string;
@@ -810,7 +823,7 @@ bool CTioRTF::load (const QString &fname)
        ansicgp.prepend ("CP");
 
        QTextCodec *codec = QTextCodec::codecForName (ansicgp.toUtf8().data());
-       qDebug() << "not unicode!";
+       //qDebug() << "not unicode!";
 
        while (i < l)
        if ((ba.at(i) == '\\') && (ba.at(i + 1) == '\''))
@@ -986,9 +999,6 @@ bool CTioEpub::load (const QString &fname)
 
   QStringList html_files;
 
-  QString source_fname;
-  QString ts;
-
   CZipper zipper;
   if (! zipper.read_as_utf8 (fname, "META-INF/container.xml"))
        return false;
@@ -1030,14 +1040,14 @@ bool CTioEpub::load (const QString &fname)
   if (xml.hasError())
       qDebug() << "xml parse error";
 
+  QStringList tags;
+  tags.append ("p");
+
   for (int i = 0; i < html_files.size(); i++)
       {
        if (! zipper.read_as_utf8 (fname, html_files.at(i)))
            return false;
 
-       QStringList tags;
-       tags.append ("p");
-
        QString t = extract_text_from_xml (zipper.string_data, tags);
        data += t;
        data += "\n";
@@ -1059,3 +1069,124 @@ QStringList CTioHandler::get_supported_exts()
   return l;
 }
 
+/*
+
+QString cp1251_to_utf16 (char *inbuf, int len)
+{
+  QString r;
+  char *outbuf = new char [len * 2];
+
+  iconv_t cd = iconv_open ("UTF-16","CP1251");
+  size_t inbytesleft;
+  size_t outbytesleft;
+
+
+  size_t s = iconv (cd, &inbuf, &inbytesleft, &outbuf, &outbytesleft);
+
+  QByteArray ba = QByteArray::fromRawData (outbuf, len * 2);
+
+  delete [] outbuf;
+
+  iconv_close (cd);
+  return r;
+}
+
+
+
+void CIconvCharsetConverter::load_charsets()
+{
+  charsets.prepend ("UTF-8");
+  charsets.prepend ("UTF-16");
+  charsets.prepend ("CP1251");
+  charsets.prepend ("KOI8-R");
+  charsets.prepend ("KOI8-U");
+  charsets.prepend ("DOS866");
+
+}
+
+
+  https://code.woboq.org/qt5/qtbase/src/corelib/codecs/qiconvcodec.cpp.html
+
+    QByteArray ba(outBytesLeft, Qt::Uninitialized);
+    char *outBytes = ba.data();
+
+  */
+/*
+QString CIconvCharsetConverter::to_utf16 (const QString &enc_from, char *inbuf, int len)
+{
+  QString r;
+  //char *outbuf = new char [len * 2 + 2]; //last 2 is bom
+  const char *inBytes = inbuf;
+
+  iconv_t cd = iconv_open ("UTF-8", enc_from.toLatin1().data());
+  size_t inbytesleft = len;
+  size_t outbytesleft = len * 4 + 2;
+
+  QByteArray ba (outbytesleft, Qt::Uninitialized);
+  char *outbuf = ba.data();
+
+  size_t total = outbytesleft;
+
+  qDebug() << "inbytesleft: " << inbytesleft;
+  qDebug() << "outbytesleft: " << outbytesleft;
+
+  while (inbytesleft > 0)
+        {
+         size_t e = iconv (cd, &inbuf, &inbytesleft, &outbuf, &outbytesleft);
+
+//         qDebug() << "e:" <<e;
+
+        }
+
+
+  //if (e != -1)
+    //r = QString::fromLatin1 (outbuf, len * 2);
+   //   r = QString::fromUtf8 (outbuf, total - outbytesleft);
+
+
+  qDebug() << "inbytesleft: " << inbytesleft;
+  qDebug() << "outbytesleft: " << outbytesleft;
+
+    //QByteArray ba = QByteArray::fromRawData (outbuf, len * 2);
+
+   //[static]QString QString::fromUtf8(const char * str, int size = -1)
+
+
+  iconv_close (cd);
+
+  //delete [] outbuf;
+
+  return QString (ba);
+}
+
+
+QStringList charsets_for_locale (const QString &loc)
+{
+  QStringList l;
+
+  return l;
+}
+*/
+/*
+char* CIconvCharsetConverter::from_utf_16 (const QString &enc_to, const QString &data)
+{
+  char *outbuf = new char [len * 2];
+
+  iconv_t cd = iconv_open ("UTF-16", enc_to.toLatin1().data());
+  size_t inbytesleft = len;
+  size_t outbytesleft = len * 2;
+
+
+  size_t e = iconv (cd, &inbuf, &inbytesleft, &outbuf, &outbytesleft);
+  if (e != -1)
+    r = QString::fromLatin1 (outbuf, len * 2);
+
+    //QByteArray ba = QByteArray::fromRawData (outbuf, len * 2);
+
+   //[static]QString QString::fromUtf8(const char * str, int size = -1)
+
+
+  iconv_close (cd);
+  return outbuf;
+}
+*/
