@@ -17,7 +17,7 @@
     </message>
     <message>
         <source>Packages</source>
-        <translation>Pakete</translation>
+        <translation type="vanished">Pakete</translation>
     </message>
     <message>
         <source>About</source>
@@ -1783,10 +1783,6 @@ To use time-based reminders, specify the time signature in 24-hour format [hh:mm
         <source>Save the current opened file with the name provided above</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>&lt;b&gt;TEA %1&lt;/b&gt; by Peter Semiletov | semiletov.org/tea&lt;br&gt;Support TEA on www.patreon.com/semiletov&lt;br&gt;Git: github.com/psemiletov/tea-qt&lt;br&gt;AUR: aur.archlinux.org/packages/tea-qt</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Capitalize sentences</source>
         <translation type="unfinished"></translation>
@@ -1795,6 +1791,30 @@ To use time-based reminders, specify the time signature in 24-hour format [hh:mm
         <source>GTK Bookmarks:</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Set as autosaving file</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Unset the autosaving file</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Autosaving</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Temporary save unsaved buffers on exit</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Autosave buffers and autosaving files (each N seconds)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>&lt;b&gt;TEA %1&lt;/b&gt; by Peter Semiletov | tea.ourproject.org&lt;br&gt;Support TEA on www.patreon.com/semiletov&lt;br&gt;Git: github.com/psemiletov/tea-qt&lt;br&gt;AUR: aur.archlinux.org/packages/tea-qt</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>CTioReadOnly</name>
